#
# SRv6 transformation module
#
from box import Box

from . import _Module

class SR(_Module):
  pass
